/*
 * Test pam_fjfi module
 * Building:
 *   gcc -fPIC -g -lpam -lpam_misc -lldap  -o check_fjfi check_fjfi.c
 */
#include <security/pam_appl.h>
#include <security/pam_misc.h>
#include <stdio.h>

static struct pam_conv conv = {
  misc_conv,
  NULL
};

int main(int argc, char *argv[])
{
  pam_handle_t *pamh=NULL;
  int retval;
  const char *user=NULL;
  
  if(argc == 2) {
    user = argv[1];
  }
  
  if(argc > 2) {
    fprintf(stderr, "Usage: check_fjfi [username]\n");
    exit(1);
  }
  
  retval = pam_start("fjfi", user, &conv, &pamh);
  if (retval != PAM_SUCCESS) {
    fprintf(stdout, "\n>>>\n>>> Not started\n>>>\n");
    exit(1);
  }
  
  retval = pam_authenticate(pamh, 0);    /* is user really user? */
  if (retval != PAM_SUCCESS) {
    fprintf(stdout, ">>>\n>>>\nNot authenticated\n>>>\n");
    exit(1);
  }
  
  retval = pam_acct_mgmt(pamh, 0);       /* permitted access? */
  if (retval != PAM_SUCCESS) {
    fprintf(stdout, ">>>\n>>>\nNot acct_mgmt\n>>>\n");
    exit(1);
  }
  
  
  /* This is where we have been authorized or not. */
  fprintf(stdout, ">>>\n>>>\nAuthenticated\n>>>\n");

  retval = pam_end(pamh,retval);
  if (retval != PAM_SUCCESS) {     /* close Linux-PAM */
    pamh = NULL;
    fprintf(stderr, "fjfi: failed to release authenticator\n");
    exit(1);
  }
  
  return ( retval == PAM_SUCCESS ? 0:1 );       /* indicate success */
}
